@@ -1,11 +1,16 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
+
 # channel_info.pl
 # print channel info
+
 use lib '.';
+
 use strict;
+use warnings;
+
 use XML::RSS;
 
-my $rss = new XML::RSS;
+my $rss = XML::RSS->new;
 $rss->parsefile(shift);
 
 print "XML encoding: ".$rss->encoding."\n";
