@@ -1,5 +1,5 @@
 package XML::RSS::Private::Output::Base;
-
+$XML::RSS::Private::Output::Base::VERSION = '1.60';
 use strict;
 use warnings;
 
@@ -44,6 +44,18 @@ sub _encode_cb {
     return $self->{_encode_cb};
 }
 
+sub _item_idx
+{
+    my $self = shift;
+
+    if (@_)
+    {
+        $self->{_item_idx} = shift;
+    }
+
+    return $self->{_item_idx};
+}
+
 sub _initialize {
     my $self = shift;
     my $args = shift;
@@ -59,6 +71,8 @@ sub _initialize {
         $self->_encode_cb(\&_default_encode);
     }
 
+    $self->_item_idx(-1);
+
     return 0;
 }
 
@@ -138,20 +152,51 @@ sub _sanitize {
 sub _out_ns_tag {
     my ($self, $prefix, $tag, $inner) = @_;
 
+    my @subtags;
+
     if (ref($inner) eq "HASH")
     {
         $self->_out("<${prefix}:${tag}");
         foreach my $attr (sort { $a cmp $b } keys(%{$inner}))
         {
-            $self->_out(
-                  q{ }
-                . $self->_sanitize($attr)
-                . q{="}
-                . $self->_encode($inner->{$attr})
-                . q{"}
-            );
+            if (ref($inner->{$attr}) eq '')
+            {
+                $self->_out(
+                      q{ }
+                    . $self->_sanitize($attr)
+                    . q{="}
+                    . $self->_encode($inner->{$attr})
+                    . q{"}
+                );
+            }
+            else
+            {
+                push(@subtags,$attr);
+            }
         }
-        $self->_out("/>\n");
+
+        if (! @subtags)
+        {
+            $self->_out("/>\n");
+        }
+        else
+        {
+            $self->_out(">\n");
+
+            foreach my $attr (sort { $a cmp $b } @subtags)
+            {
+                if (ref($inner->{$attr}))
+                {
+                    _out_ns_tag($self, $prefix, $tag, $inner->{$attr});
+                }
+            }
+
+            $self->_out("</${prefix}:${tag}>\n");
+        }
+    }
+    elsif (ref($inner) eq 'ARRAY')
+    {
+        map { $self->_out_ns_tag($prefix, $tag, $_) } @{ $inner };
     }
     else
     {
@@ -497,9 +542,22 @@ sub _out_item_desc {
 sub _output_common_item_tags {
     my ($self, $item) = @_;
 
+    my @fields = (qw( title link ));
+
+    my $defined = $self->_get_item_defined;
+
+    if (! $defined) {
+        foreach my $f (@fields)
+        {
+            if (!defined($item->{$f})) {
+                die qq/Item No. / . $self->_item_idx() . qq/ is missing the "$f" field./;
+            }
+        }
+    }
+
     $self->_output_multiple_tags(
-        {ext => $item, 'defined' => $self->_get_item_defined},
-        [qw(title link)],);
+        {ext => $item, type => 'item', idx => $self->_item_idx(), 'defined' => $defined,},
+        [@fields],);
 
     $self->_out_item_desc($item);
 
@@ -849,11 +907,22 @@ sub _out_seq_items {
     # Seq items
     $self->_out("<items>\n <rdf:Seq>\n");
 
+    my $idx = 0;
     foreach my $item (@{$self->_main->_get_items()}) {
+
+        my $about_text = $self->_get_item_about($item);
+
+        if (!defined($about_text)) {
+            die qq/Item No. $idx is missing "about" or "link" fields./;
+        }
+
         $self->_out('  <rdf:li rdf:resource="' .
-            $self->_encode($self->_get_item_about($item)) .
+            $self->_encode($about_text) .
             '" />' . "\n");
     }
+    continue {
+        $idx++;
+    }
 
     $self->_out(" </rdf:Seq>\n</items>\n");
 }
@@ -1000,9 +1069,13 @@ sub _output_single_item {
 sub _output_items {
     my $self = shift;
 
+    $self->_item_idx(0);
     foreach my $item (@{$self->_get_filtered_items}) {
         $self->_output_single_item($item);
     }
+    continue {
+        $self->_item_idx($self->_item_idx()+1);
+    }
 }
 
 sub _output_main_elements {
@@ -1132,5 +1205,158 @@ sub _modules {
 }
 
 1;
+
 __END__
 
+=pod
+
+=head1 VERSION
+
+version 1.60
+
+=head1 METHODS
+
+=head2 channel
+
+Internal use.
+
+=head2 image
+
+Internal use.
+
+=head2 new
+
+Internal use.
+
+=head2 textinput
+
+Internal use.
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2001 by Various.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-XML-RSS/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc XML::RSS::Private::Output::Base
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/XML-RSS>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/XML-RSS>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-RSS>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/XML-RSS>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/XML-RSS>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/XML-RSS>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/X/XML-RSS>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=XML-RSS>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=XML::RSS>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-xml-rss at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-RSS>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/perl-XML-RSS>
+
+  git clone git://github.com/shlomif/perl-XML-RSS.git
+
+=cut
